@@ -88,7 +88,7 @@ QtObject {
         anchors.bottom: column.bottom
         anchors.topMargin: inToolBar ? Kirigami.Units.largeSpacing : 0
         anchors.bottomMargin: inToolBar ? Kirigami.Units.largeSpacing : 0
-        Kirigami.Theme.colorSet: Kirigami.Theme.Window
+        Kirigami.Theme.colorSet: Kirigami.Theme.Header
         Kirigami.Theme.inherit: false
     }
 
@@ -98,7 +98,7 @@ QtObject {
         anchors.top: column.top
         anchors.right: column.right
         anchors.bottom: column.bottom
-        Kirigami.Theme.colorSet: Kirigami.Theme.Window
+        Kirigami.Theme.colorSet: Kirigami.Theme.Header
         Kirigami.Theme.inherit: false
     }
 }
@@ -379,7 +379,7 @@ ContentItem::ContentItem(ColumnView *parent)
     m_slideAnim->setPropertyName("x");
     // NOTE: the duration will be taken from kirigami units upon classBegin
     m_slideAnim->setDuration(0);
-    m_slideAnim->setEasingCurve(QEasingCurve(QEasingCurve::InOutQuad));
+    m_slideAnim->setEasingCurve(QEasingCurve(QEasingCurve::OutExpo));
     connect(m_slideAnim, &QPropertyAnimation::finished, this, [this]() {
         if (!m_view->currentItem()) {
             m_view->setCurrentIndex(m_items.indexOf(m_viewAnchorItem));
@@ -424,11 +424,11 @@ void ContentItem::animateX(qreal newX)
 
 void ContentItem::snapToItem()
 {
-    QQuickItem *firstItem = childAt(viewportLeft(), 0);
+    QQuickItem *firstItem = childAt(viewportLeft(), height() / 2);
     if (!firstItem) {
         return;
     }
-    QQuickItem *nextItem = childAt(firstItem->x() + firstItem->width() + 1, 0);
+    QQuickItem *nextItem = childAt(firstItem->x() + firstItem->width() + 1, height() / 2);
 
     // need to make the last item visible?
     if (nextItem && //
@@ -526,7 +526,8 @@ void ContentItem::layoutItems()
                     sepWidth = (sep ? sep->width() : 0);
                 }
                 const qreal width = childWidth(child);
-                const qreal pageX = std::clamp(partialWidth, -x(), -x() + m_view->width() - child->width());
+                const qreal widthDiff = std::max(0.0, m_view->width() - child->width()); // it's possible for the view width to be smaller than the child width
+                const qreal pageX = std::clamp(partialWidth, -x(), -x() + widthDiff);
                 qreal headerHeight = .0;
                 qreal footerHeight = .0;
                 if (QQuickItem *header = attached->globalHeader()) {
@@ -708,8 +709,10 @@ void ContentItem::updateVisibleItems()
                 m_visibleItems.removeAll(item);
             });
             attached->setInViewport(true);
+            item->setEnabled(true);
         } else {
             attached->setInViewport(false);
+            item->setEnabled(false);
         }
     }
 
@@ -1807,7 +1810,7 @@ void ColumnView::classBegin()
     syncColumnWidth();
 
     auto syncDuration = [this]() {
-        m_contentItem->m_slideAnim->setDuration(QmlComponentsPoolSingleton::instance(qmlEngine(this))->m_units->longDuration());
+        m_contentItem->m_slideAnim->setDuration(QmlComponentsPoolSingleton::instance(qmlEngine(this))->m_units->veryLongDuration());
         Q_EMIT scrollDurationChanged();
     };
 
